@@ -11,6 +11,8 @@
 #	Copyright (C) 1999, 2000, Andrew Arensburger.
 #	You may distribute this file under the terms of the Artistic
 #	License, as specified in the README file.
+#
+# $Id: Raw.pm,v 1.11 2005/03/29 02:46:03 arensb Exp $
 
 use strict;
 package Palm::Raw;
@@ -18,7 +20,7 @@ use Palm::PDB;
 use vars qw( $VERSION @ISA );
 
 # One liner, to allow MakeMaker to work.
-$VERSION = '1.011_01';
+$VERSION = do { my @r = (q$Revision: 1.11 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 
 @ISA = qw( Palm::PDB );
 
@@ -178,17 +180,9 @@ sub PackResource
 1;
 __END__
 
-=head1 SOURCE CONTROL
-
-The source is in Github:
-
-	http://github.com/briandfoy/p5-Palm/tree/master
-	
 =head1 AUTHOR
 
-Alessandro Zummo, C<< <a.zummo@towertech.it> >>
-
-Currently maintained by brian d foy, C<< <bdfoy@cpan.org> >>
+Andrew Arensburger E<lt>arensb@ooblick.comE<gt>
 
 =head1 SEE ALSO
 
